Inspect the metabolite annotation provenance stored in a SpaMTP object
Source:R/AnnotationStore.R
AnnotationInfo.RdReports whether downstream pathway functions will use the current indexed, scored RaMP annotation pipeline or a legacy mass-match result.