analytehaspathway: A dataframe containing RAMP_pathway ID's
Source:R/Cleaned_Reference_Metabolite_Databases.R
analytehaspathway.RdPruned from RaMP-DB 3.0.7. This object maps analytes to pathways and records the contributing pathway source.

R/Cleaned_Reference_Metabolite_Databases.R
analytehaspathway.RdPruned from RaMP-DB 3.0.7. This object maps analytes to pathways and records the contributing pathway source.